# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMeshPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkMeshSourcePython
else:
    import _itkMeshSourcePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkPointSetPython
import itk.itkVectorContainerPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkArrayPython
import itk.itkMeshBasePython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython

def itkMeshSourceMD2_New():
    return itkMeshSourceMD2.New()

class itkMeshSourceMD2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMD2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMD2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMD2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshD2
        GetOutput(self, idx) -> itkMeshD2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMD2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshD2 *

        """
        return _itkMeshSourcePython.itkMeshSourceMD2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMD2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMD2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMD2

        Create a new object of the class itkMeshSourceMD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMD2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMD2_swigregister(itkMeshSourceMD2)

def itkMeshSourceMD3_New():
    return itkMeshSourceMD3.New()

class itkMeshSourceMD3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMD3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMD3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMD3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshD3
        GetOutput(self, idx) -> itkMeshD3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMD3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshD3 *

        """
        return _itkMeshSourcePython.itkMeshSourceMD3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMD3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMD3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMD3

        Create a new object of the class itkMeshSourceMD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMD3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMD3_swigregister(itkMeshSourceMD3)

def itkMeshSourceMF2_New():
    return itkMeshSourceMF2.New()

class itkMeshSourceMF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMF2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMF2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMF2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshF2
        GetOutput(self, idx) -> itkMeshF2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMF2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshF2 *

        """
        return _itkMeshSourcePython.itkMeshSourceMF2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMF2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMF2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMF2

        Create a new object of the class itkMeshSourceMF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMF2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMF2_swigregister(itkMeshSourceMF2)

def itkMeshSourceMF3_New():
    return itkMeshSourceMF3.New()

class itkMeshSourceMF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMF3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMF3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMF3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshF3
        GetOutput(self, idx) -> itkMeshF3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMF3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshF3 *

        """
        return _itkMeshSourcePython.itkMeshSourceMF3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMF3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMF3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMF3

        Create a new object of the class itkMeshSourceMF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMF3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMF3_swigregister(itkMeshSourceMF3)

def itkMeshSourceMSS2_New():
    return itkMeshSourceMSS2.New()

class itkMeshSourceMSS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMSS2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMSS2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMSS2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshSS2
        GetOutput(self, idx) -> itkMeshSS2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMSS2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshSS2 *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMSS2

        Create a new object of the class itkMeshSourceMSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMSS2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMSS2_swigregister(itkMeshSourceMSS2)

def itkMeshSourceMSS3_New():
    return itkMeshSourceMSS3.New()

class itkMeshSourceMSS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMSS3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMSS3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMSS3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshSS3
        GetOutput(self, idx) -> itkMeshSS3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMSS3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshSS3 *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMSS3

        Create a new object of the class itkMeshSourceMSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMSS3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMSS3_swigregister(itkMeshSourceMSS3)

def itkMeshSourceMUC2_New():
    return itkMeshSourceMUC2.New()

class itkMeshSourceMUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMUC2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMUC2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMUC2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshUC2
        GetOutput(self, idx) -> itkMeshUC2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMUC2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshUC2 *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMUC2

        Create a new object of the class itkMeshSourceMUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMUC2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMUC2_swigregister(itkMeshSourceMUC2)

def itkMeshSourceMUC3_New():
    return itkMeshSourceMUC3.New()

class itkMeshSourceMUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourceMUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourceMUC3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourceMUC3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourceMUC3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshUC3
        GetOutput(self, idx) -> itkMeshUC3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourceMUC3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshUC3 *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourceMUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourceMUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourceMUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourceMUC3

        Create a new object of the class itkMeshSourceMUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourceMUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourceMUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourceMUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourceMUC3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourceMUC3_swigregister(itkMeshSourceMUC3)

def itkMeshSourcePSD2_New():
    return itkMeshSourcePSD2.New()

class itkMeshSourcePSD2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSD2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSD2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSD2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetD2
        GetOutput(self, idx) -> itkPointSetD2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSD2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetD2 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSD2

        Create a new object of the class itkMeshSourcePSD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSD2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSD2_swigregister(itkMeshSourcePSD2)

def itkMeshSourcePSD3_New():
    return itkMeshSourcePSD3.New()

class itkMeshSourcePSD3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSD3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSD3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSD3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetD3
        GetOutput(self, idx) -> itkPointSetD3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSD3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetD3 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSD3

        Create a new object of the class itkMeshSourcePSD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSD3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSD3_swigregister(itkMeshSourcePSD3)

def itkMeshSourcePSF2_New():
    return itkMeshSourcePSF2.New()

class itkMeshSourcePSF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSF2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSF2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSF2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetF2
        GetOutput(self, idx) -> itkPointSetF2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSF2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetF2 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSF2

        Create a new object of the class itkMeshSourcePSF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSF2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSF2_swigregister(itkMeshSourcePSF2)

def itkMeshSourcePSF3_New():
    return itkMeshSourcePSF3.New()

class itkMeshSourcePSF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSF3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSF3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSF3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetF3
        GetOutput(self, idx) -> itkPointSetF3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSF3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetF3 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSF3

        Create a new object of the class itkMeshSourcePSF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSF3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSF3_swigregister(itkMeshSourcePSF3)

def itkMeshSourcePSSS2_New():
    return itkMeshSourcePSSS2.New()

class itkMeshSourcePSSS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSSS2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSSS2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSSS2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetSS2
        GetOutput(self, idx) -> itkPointSetSS2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetSS2 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSSS2

        Create a new object of the class itkMeshSourcePSSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSSS2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSSS2_swigregister(itkMeshSourcePSSS2)

def itkMeshSourcePSSS3_New():
    return itkMeshSourcePSSS3.New()

class itkMeshSourcePSSS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSSS3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSSS3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSSS3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetSS3
        GetOutput(self, idx) -> itkPointSetSS3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetSS3 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSSS3

        Create a new object of the class itkMeshSourcePSSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSSS3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSSS3_swigregister(itkMeshSourcePSSS3)

def itkMeshSourcePSUC2_New():
    return itkMeshSourcePSUC2.New()

class itkMeshSourcePSUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSUC2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSUC2_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSUC2_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetUC2
        GetOutput(self, idx) -> itkPointSetUC2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC2_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetUC2 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC2_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC2_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSUC2

        Create a new object of the class itkMeshSourcePSUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSUC2 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSUC2_swigregister(itkMeshSourcePSUC2)

def itkMeshSourcePSUC3_New():
    return itkMeshSourcePSUC3.New()

class itkMeshSourcePSUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMeshSourcePSUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMeshSourcePSUC3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMeshSourcePSUC3_Pointer"""
        return _itkMeshSourcePython.itkMeshSourcePSUC3_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPointSetUC3
        GetOutput(self, idx) -> itkPointSetUC3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC3_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkPointSetUC3 *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC3_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC3_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkMeshSourcePython.delete_itkMeshSourcePSUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMeshSourcePSUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMeshSourcePython.itkMeshSourcePSUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMeshSourcePSUC3

        Create a new object of the class itkMeshSourcePSUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMeshSourcePSUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMeshSourcePSUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMeshSourcePSUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMeshSourcePSUC3 in _itkMeshSourcePython:
_itkMeshSourcePython.itkMeshSourcePSUC3_swigregister(itkMeshSourcePSUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def mesh_source(*args,  output: itkt.PointSet=...,**kwargs):
    """Functional interface for MeshSource"""
    import itk

    kwarg_typehints = { 'output':output }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.MeshSource.New(*args, **kwargs)

    return instance.__internal_call__()

def mesh_source_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMesh.MeshSource
    mesh_source.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    mesh_source.__doc__ = filter_object.__doc__



